==> pmb8.0.1.0.zip: pmb/includes/search_queries/specials/combine_empr/search.class.php <==
<?php
// +-------------------------------------------------+
//  2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: search.class.php,v 1.9.2.1 2024/09/06 10:40:53 dgoron Exp $

if (stristr($_SERVER['REQUEST_URI'], ".class.php")) die("no access");

global $msg,$lang,$charset,$base_path,$class_path,$include_path;
require_once($class_path."/searcher.class.php");

//Classe de gestion de la recherche spcial "combine"

class combine_search_empr {
	public $id;
	public $n_ligne;
	public $params;
	public $search;

	//Constructeur
    public function __construct($id,$n_ligne,$params,&$search) {
    	$this->id=$id;
    	$this->n_ligne=$n_ligne;
    	$this->params=$params;
    	$this->search=&$search;
    }
    
    //fonction de rcupration des oprateurs disponibles pour ce champ spcial (renvoie un tableau d'oprateurs)
    public function get_op() {
    	$operators = array();
    	if (is_countable($_SESSION["session_history"]) && count($_SESSION["session_history"])!=0) {
    		$operators["EQ"]="=";
    	}
    	return $operators;
    }
    
    //fonction de rcupration de l'affichage de la saisie du critre
    public function get_input_box() {
    	global $msg;
    	global $charset;
    	global $get_input_box_id;
    	
    	//Rcupration de la valeur de saisie
    	$valeur_="field_".$this->n_ligne."_s_".$this->id;
    	global ${$valeur_};
    	$valeur=${$valeur_};
		
    	//parcours de l'historique des recherches
    	if (is_countable($_SESSION["session_history"]) && count($_SESSION["session_history"])) {
    		if(!$get_input_box_id)$get_input_box_id="input_box_id_0";
	    	else	$get_input_box_id++;
	    	   	
	    	//$r="&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td></tr><tr><td>&nbsp;</td><td>&nbsp;</td><td colspan='3'>";
	    	$r .="<script type='text/javascript' src='./javascript/tablist.js'></script>
	    	<div id='$get_input_box_id' class='notice-parent'>
            ".get_expandBase_button($get_input_box_id)."
			<span class='notice-heada'>		
				<input type='hidden' name='field_".$this->n_ligne."_s_".$this->id."[]'  id='".$get_input_box_id."_value' value='!!value_selected!!'/>	
				<label id='".$get_input_box_id."_label' >!!label_selected!!</label>
			</span>
			
			</div>
			<div id='$get_input_box_id"."Child' class='notice-child' style='margin-bottom:6px;display:none;width:94%' $max>
				<table class='table-no-border'>
				!!contenu!!
				</table>
			</div>
			";
			
    		if ($valeur) {
    			if ($valeur[0]=='-1') {
    				$r=str_replace("!!value_selected!!","-1", $r);
    				$r=str_replace("!!label_selected!!",$msg["default_search_histo"], $r);
    			}
    		} else {
    			$r=str_replace("!!value_selected!!","-1", $r);
    			$r=str_replace("!!label_selected!!",$msg["default_search_histo"], $r);   			
    		}

    		$style_odd="class='odd' onmouseover=\"this.className='surbrillance'\" onmouseout=\"this.className='odd'\" ";
    		$style_even="class='even' onmouseover=\"this.className='surbrillance'\" onmouseout=\"this.className='even'\" ";
    		$onclick="onClick=\"document.getElementById('".$get_input_box_id."_label').innerHTML='".addslashes($msg["default_search_histo"])."';document.getElementById('".$get_input_box_id."_value').value='-1';expandBase('$get_input_box_id', true); return false;\"";

    		$liste="<tr $style_even><td $onclick >".$msg["default_search_histo"]."</td></tr>";
    		$pair = 0;
    	    for ($i=count($_SESSION["session_history"])-1; $i>=0; $i--) {
    			if ($_SESSION["session_history"][$i]["EMPR"]) {
    				$temp=html_entity_decode(strip_tags(($i+1).") ".$_SESSION["session_history"][$i]["QUERY"]["HUMAN_QUERY"]),ENT_QUOTES,$charset);
    				$onclick="onClick=\"document.getElementById('".$get_input_box_id."_label').innerHTML=this.innerHTML;document.getElementById('".$get_input_box_id."_value').value='$i';expandBase('$get_input_box_id', true); return false;\"";
    				$pair = 1 - $pair;
    				if($pair) {
    				    $style = $style_odd;
    				} else {
    				    $style = $style_even;
    				}
    				$liste.="<tr $style><td $onclick >$temp</td></tr>";

    				if ($valeur) {
    					if ($valeur[0]==$i) {
    	    				$r=str_replace("!!value_selected!!","$i", $r);
    						$r=str_replace("!!label_selected!!",$temp, $r);   						
    					}
    				} 
    			}
    		}
    		$r=str_replace("!!contenu!!",$liste, $r);
    	} else {
    		$r .= "<b>".$msg["histo_empty"]."</b>";
    	}
    	return $r;
    }
    
    //fonction de conversion de la saisie en quelque chose de compatible avec l'environnement
    public function transform_input() {
    }
    
    //fonction de cration de la requte (retourne une table temporaire)
    public function make_search() {
    	global $search;
    	    	    	
    	//Rcupration de la valeur de saisie
    	$valeur_="field_".$this->n_ligne."_s_".$this->id;
    	global ${$valeur_};
    	$valeur=${$valeur_};
    	
    	if (!$this->is_empty($valeur)) {
    		
    		//enregistrement de l'environnement courant
    		$this->search->push();
    		//Rcupration et mise en variables globales des valeurs de l'historique
    		if ($_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"]["search"][0]) {
    			$search=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"]["search"];
    			//Pour chaque champ
    			for ($i=0; $i<count($search); $i++) {
    			
    				//Rcupration de l'oprateur
    				$op="op_".$i."_".$search[$i];
    				global ${$op};
    				${$op}=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"][$op];
    			    			
    				//Rcupration du contenu de la recherche
    				$field_="field_".$i."_".$search[$i];
    				global ${$field_};
    				${$field_}=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"][$field_];
    				$field=${$field_};
    		
    				//Rcupration de l'oprateur inter-champ
    				$inter="inter_".$i."_".$search[$i];
    				global ${$inter};
    				${$inter}=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"][$inter];
    			    		
    				//Rcupration des variables auxiliaires
    				$fieldvar_="fieldvar_".$i."_".$search[$i];
    				global ${$fieldvar_};
    				${$fieldvar_}=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"][$fieldvar_];
    				$fieldvar=${$fieldvar_};
    			}
    		} else {
    			if (!$_SESSION["session_history"][$valeur[0]]["EMPR"]["GET"]["idcaddie"]) {
    				switch ($_SESSION["session_history"][$valeur[0]]["EMPR"]["GET"]["mode"]){
    					case 0:
    						searcher_title::convert_simple_multi($valeur[0]);	
    					break;
    					case 1:			
    						searcher_subject::convert_simple_multi($valeur[0]);	
    					break;
    					case 2:
    						searcher_publisher::convert_simple_multi($valeur[0]);	
    					break;
    				}
    			} else {
    				$op_="EQ";
    				$valeur_champ=$_SESSION["session_history"][$valeur[0]]["EMPR"]["GET"]["idcaddie"];
    				if(empty($search)) {
    					$search=array();
    				}
    				$search[0]="f_11";
					//oprateur
    				$op="op_0_".$search[0];
    				global ${$op};
    				${$op}=$op_;
    		    			
    				//contenu de la recherche
    				$field = "field_0_".$search[0];
    				$field_array_ = array();
    				$field_array_[0] = $valeur_champ;
    				global ${$field};
    				${$field} = $field_array_;
    	    	
    				//oprateur inter-champ
    				$inter="inter_0_".$search[0];
    				global ${$inter};
    				${$inter}="";
    			    		
    				//variables auxiliaires
    				$fieldvar_="fieldvar_0_".$search[0];
    				global ${$fieldvar_};
    				${$fieldvar_}="";
    				$fieldvar=${$fieldvar_};	
    			}	
    		}
    			    		    		    		
    		//on instancie la classe search avec le nom de la nouvelle table temporaire
    		$table_tempo="";
			if ($_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"]["search"][0]) {
				$sc=new search(false,"search_fields_empr");
				
				$table_tempo=$sc->make_search("tempo_".$valeur[0]);
			}
						
			//restauration de l'environnement courant
			$this->search->pull();
			return $table_tempo;
    	} 
    }
    
    //fonction de traduction littrale de la requte effectue (renvoie un tableau des termes saisis)
    public function make_human_query() {
    	
    	$litteral=array();
    			
    	//Rcupration de la valeur de saisie 
    	$valeur_="field_".$this->n_ligne."_s_".$this->id;
    	global ${$valeur_};
    	$valeur=${$valeur_};
    	if (!$this->is_empty($valeur)) {
    		$litteral[0]= $_SESSION["session_history"][$valeur[0]]["EMPR"]["HUMAN_QUERY"];
    	}	
		return $litteral;    
    }
    
    //fonction de vrification du champ saisi ou slectionn
    public function is_empty($valeur) {
    	if (count($valeur)) {
    		if ($valeur[0]=="-1") return true;
    			else return ($valeur[0] === false);
    	} else {
    		return true;
    	}
    }
    
     //fonction de dcoupage d'une chaine trop longue
    public function cutlongwords($valeur,$size=50) {
    	if (strlen($valeur)>=$size) {
    		$pos=strrpos(substr($valeur,0,$size)," ");
    		if ($pos) {
    			$valeur=substr($valeur,0,$pos+1)."...";
    		} 
    	}
    	return $valeur;		
    }
}
?>

==> pmb8.0.1.23.zip: pmb/includes/search_queries/specials/combine_empr/search.class.php <==
<?php
// +-------------------------------------------------+
//  2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: search.class.php,v 1.9.2.1.2.2 2025/09/16 10:22:58 tsamson Exp $

if (stristr($_SERVER['REQUEST_URI'], ".class.php")) die("no access");

global $msg,$lang,$charset,$base_path,$class_path,$include_path;
require_once($class_path."/searcher.class.php");

//Classe de gestion de la recherche spcial "combine"

class combine_search_empr {
	public $id;
	public $n_ligne;
	public $params;
	public $search;

	//Constructeur
    public function __construct($id,$n_ligne,$params,&$search) {
    	$this->id=$id;
    	$this->n_ligne=$n_ligne;
    	$this->params=$params;
    	$this->search=&$search;
    }

    //fonction de rcupration des oprateurs disponibles pour ce champ spcial (renvoie un tableau d'oprateurs)
    public function get_op() {
    	$operators = array();
    	if (is_countable($_SESSION["session_history"]) && count($_SESSION["session_history"])!=0) {
    		$operators["EQ"]="=";
    	}
    	return $operators;
    }

    //fonction de rcupration de l'affichage de la saisie du critre
    public function get_input_box() {
    	global $msg;
    	global $charset;
    	global $get_input_box_id;

    	//Rcupration de la valeur de saisie
    	$valeur_="field_".$this->n_ligne."_s_".$this->id;
    	global ${$valeur_};
    	$valeur=${$valeur_};

    	//parcours de l'historique des recherches
    	if (is_countable($_SESSION["session_history"]) && count($_SESSION["session_history"])) {
    		if (!$get_input_box_id) {
				$get_input_box_id="input_box_id_0";
			} else {
				$get_input_box_id++;
			}

	    	//$r="&nbsp;</td><td>&nbsp;</td><td>&nbsp;</td></tr><tr><td>&nbsp;</td><td>&nbsp;</td><td colspan='3'>";
	    	$r ="<script type='text/javascript' src='./javascript/tablist.js'></script>
	    	<div id='$get_input_box_id' class='notice-parent'>
            ".get_expandBase_button($get_input_box_id)."
			<span class='notice-heada'>
				<input type='hidden' name='field_".$this->n_ligne."_s_".$this->id."[]'  id='".$get_input_box_id."_value' value='!!value_selected!!'/>
				<label id='".$get_input_box_id."_label' >!!label_selected!!</label>
			</span>

			</div>
			<div id='$get_input_box_id"."Child' class='notice-child' style='margin-bottom:6px;display:none;width:94%'>
				<table class='table-no-border'>
				!!contenu!!
				</table>
			</div>
			";

    		if ($valeur) {
    			if ($valeur[0]=='-1') {
    				$r=str_replace("!!value_selected!!","-1", $r);
    				$r=str_replace("!!label_selected!!",$msg["default_search_histo"], $r);
    			}
    		} else {
    			$r=str_replace("!!value_selected!!","-1", $r);
    			$r=str_replace("!!label_selected!!",$msg["default_search_histo"], $r);
    		}

    		$style_odd="class='odd' onmouseover=\"this.className='surbrillance'\" onmouseout=\"this.className='odd'\" ";
    		$style_even="class='even' onmouseover=\"this.className='surbrillance'\" onmouseout=\"this.className='even'\" ";
    		$onclick="onClick=\"document.getElementById('".$get_input_box_id."_label').innerHTML='".addslashes($msg["default_search_histo"])."';document.getElementById('".$get_input_box_id."_value').value='-1';expandBase('$get_input_box_id', true); return false;\"";

    		$liste="<tr $style_even><td $onclick >".$msg["default_search_histo"]."</td></tr>";
    		$pair = 0;
    	    for ($i=count($_SESSION["session_history"])-1; $i>=0; $i--) {
    			if ($_SESSION["session_history"][$i]["EMPR"]) {
    				$temp=html_entity_decode(strip_tags(($i+1).") ".$_SESSION["session_history"][$i]["QUERY"]["HUMAN_QUERY"]),ENT_QUOTES,$charset);
    				$onclick="onClick=\"document.getElementById('".$get_input_box_id."_label').innerHTML=this.innerHTML;document.getElementById('".$get_input_box_id."_value').value='$i';expandBase('$get_input_box_id', true); return false;\"";
    				$pair = 1 - $pair;
    				if($pair) {
    				    $style = $style_odd;
    				} else {
    				    $style = $style_even;
    				}
    				$liste.="<tr $style><td $onclick >$temp</td></tr>";

    				if ($valeur) {
    					if ($valeur[0]==$i) {
    	    				$r=str_replace("!!value_selected!!","$i", $r);
    						$r=str_replace("!!label_selected!!",$temp, $r);
    					}
    				}
    			}
    		}
    		$r=str_replace("!!contenu!!",$liste, $r);
    	} else {
    		$r = "<b>".$msg["histo_empty"]."</b>";
    	}
    	return $r;
    }

    //fonction de conversion de la saisie en quelque chose de compatible avec l'environnement
    public function transform_input() {
    }

    //fonction de cration de la requte (retourne une table temporaire)
    public function make_search() {
    	global $search;

    	//Rcupration de la valeur de saisie
    	$valeur_="field_".$this->n_ligne."_s_".$this->id;
    	global ${$valeur_};
    	$valeur=${$valeur_};

    	if (!$this->is_empty($valeur)) {

    		//enregistrement de l'environnement courant
    		$this->search->push();
    		//Rcupration et mise en variables globales des valeurs de l'historique
    		if ($_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"]["search"][0]) {
    			$search=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"]["search"];
    			//Pour chaque champ
    			for ($i=0; $i<count($search); $i++) {

    				//Rcupration de l'oprateur
    				$op="op_".$i."_".$search[$i];
    				global ${$op};
    				${$op}=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"][$op];

    				//Rcupration du contenu de la recherche
    				$field_="field_".$i."_".$search[$i];
    				global ${$field_};
    				${$field_}=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"][$field_];
    				$field=${$field_};

    				//Rcupration de l'oprateur inter-champ
    				$inter="inter_".$i."_".$search[$i];
    				global ${$inter};
    				${$inter}=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"][$inter];

    				//Rcupration des variables auxiliaires
    				$fieldvar_="fieldvar_".$i."_".$search[$i];
    				global ${$fieldvar_};
    				${$fieldvar_}=$_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"][$fieldvar_];
    				$fieldvar=${$fieldvar_};
    			}
    		} else {
    			if (!$_SESSION["session_history"][$valeur[0]]["EMPR"]["GET"]["idcaddie"]) {
    				switch ($_SESSION["session_history"][$valeur[0]]["EMPR"]["GET"]["mode"]){
    					case 0:
    						searcher_title::convert_simple_multi($valeur[0]);
    					break;
    					case 1:
    						searcher_subject::convert_simple_multi($valeur[0]);
    					break;
    					case 2:
    						searcher_publisher::convert_simple_multi($valeur[0]);
    					break;
    				}
    			} else {
    				$op_="EQ";
    				$valeur_champ=$_SESSION["session_history"][$valeur[0]]["EMPR"]["GET"]["idcaddie"];
    				if(empty($search)) {
    					$search=array();
    				}
    				$search[0]="f_11";
					//oprateur
    				$op="op_0_".$search[0];
    				global ${$op};
    				${$op}=$op_;

    				//contenu de la recherche
    				$field = "field_0_".$search[0];
    				$field_array_ = array();
    				$field_array_[0] = $valeur_champ;
    				global ${$field};
    				${$field} = $field_array_;

    				//oprateur inter-champ
    				$inter="inter_0_".$search[0];
    				global ${$inter};
    				${$inter}="";

    				//variables auxiliaires
    				$fieldvar_="fieldvar_0_".$search[0];
    				global ${$fieldvar_};
    				${$fieldvar_}="";
    				$fieldvar=${$fieldvar_};
    			}
    		}

    		//on instancie la classe search avec le nom de la nouvelle table temporaire
    		$table_tempo="";
			if ($_SESSION["session_history"][$valeur[0]]["QUERY"]["POST"]["search"][0]) {
				$sc=new search(false,"search_fields_empr");

				$table_tempo=$sc->make_search("tempo_".$valeur[0]);
			}

			//restauration de l'environnement courant
			$this->search->pull();
			return $table_tempo;
    	}
    }

    //fonction de traduction littrale de la requte effectue (renvoie un tableau des termes saisis)
    public function make_human_query() {

    	$litteral=array();

    	//Rcupration de la valeur de saisie
    	$valeur_="field_".$this->n_ligne."_s_".$this->id;
    	global ${$valeur_};
    	$valeur=${$valeur_};
    	if (!$this->is_empty($valeur)) {
    		$litteral[0]= $_SESSION["session_history"][$valeur[0]]["EMPR"]["HUMAN_QUERY"];
    	}
		return $litteral;
    }

    //fonction de vrification du champ saisi ou slectionn
    public function is_empty($valeur) {
        if (is_countable($valeur) && count($valeur)) {
    		if ($valeur[0]=="-1") return true;
    			else return ($valeur[0] === false);
    	} else {
    		return true;
    	}
    }

     //fonction de dcoupage d'une chaine trop longue
    public function cutlongwords($valeur,$size=50) {
    	if (strlen($valeur)>=$size) {
    		$pos=strrpos(substr($valeur,0,$size)," ");
    		if ($pos) {
    			$valeur=substr($valeur,0,$pos+1)."...";
    		}
    	}
    	return $valeur;
    }
}
?>
